# Contributing

If you would like to contribute some failing examples to this test suite, please contact the maintainer (cody.c.baker.phd@gamil.com) prior to opening a pull request.

There are multiple fields that may require anonymization prior to being shared openly.



# easy_lines.log

For DANDI, the timestamps of each line for a log file correspond to the `YEAR/MONTH/DAY.log` of the directory.

The extraction tools are not dependent on this structure and so to simplify the test cases, we only maintain two files.

The 'easy' collection contains the most typical lines which follow a nice, simple, and reliable structure.



# hard_lines.log

The 'hard' collection contains many of the most difficult lines to extract as they were found from error reports.
